==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dd/d39/classScriptInstance.js <==
var classScriptInstance =
[
    [ "ScriptInstance", "dd/d39/classScriptInstance.html#af38fe06832c537f369d376215c4c69ca", null ],
    [ "~ScriptInstance", "dd/d39/classScriptInstance.html#a7225244e2a3a774ca3ac704a5e14b58f", null ],
    [ "CallLoad", "dd/d39/classScriptInstance.html#a8ee5b1ffbff379e1edb4beb9009609c9", null ],
    [ "CollectGarbage", "dd/d39/classScriptInstance.html#a4b31a3351ff66fbfe23877ed764fbbea", null ],
    [ "Continue", "dd/d39/classScriptInstance.html#aab6ccc82d56c4fd0bd194e83de3c1ae1", null ],
    [ "Died", "dd/d39/classScriptInstance.html#a1be2376dfdb1b414f89fa8e84835eba9", null ],
    [ "DoCommandCallback", "dd/d39/classScriptInstance.html#a176da3e63f75a97aba1eda25d4efb081", null ],
    [ "DoCommandReturn", "dd/d39/classScriptInstance.html#a3a2942c82ee4448280f2fc38d70a730d", null ],
    [ "DoCommandReturnGoalID", "dd/d39/classScriptInstance.html#a631e44a7f9f88430b84d7391cb5d4bee", null ],
    [ "DoCommandReturnGroupID", "dd/d39/classScriptInstance.html#a63fdbc5eb56df504c9550b312302b5be", null ],
    [ "DoCommandReturnSignID", "dd/d39/classScriptInstance.html#ad282a9e3c9ee1fcc86c5ee65f09a0269", null ],
    [ "DoCommandReturnStoryPageElementID", "dd/d39/classScriptInstance.html#a4b8add72ae20706d80355e472c655613", null ],
    [ "DoCommandReturnStoryPageID", "dd/d39/classScriptInstance.html#af0e89da5f19d101c0f735300fb5881b8", null ],
    [ "DoCommandReturnVehicleID", "dd/d39/classScriptInstance.html#a618bcb3251946270e392ca335ceae293", null ],
    [ "FindLibrary", "dd/d39/classScriptInstance.html#aa240df381cec1162969036894adaf097", null ],
    [ "GameLoop", "dd/d39/classScriptInstance.html#ab76bed5f630ca1c9f67254a52241759f", null ],
    [ "GetController", "dd/d39/classScriptInstance.html#ab5e38aa6be21cb868724a906ab691b64", null ],
    [ "GetDoCommandCallback", "dd/d39/classScriptInstance.html#a77474f760f63c96c8ac633dacd9fb9d1", null ],
    [ "GetLogPointer", "dd/d39/classScriptInstance.html#ae6de76c5aee031f5f6eb84865875e841", null ],
    [ "GetOpsTillSuspend", "dd/d39/classScriptInstance.html#adc95ae26f0623017b8cb6ab9dba1668b", null ],
    [ "GetSetting", "dd/d39/classScriptInstance.html#ae75399348a1920f935c840b828d7d274", null ],
    [ "GetStorage", "dd/d39/classScriptInstance.html#a186863f4bf0683092173c1286c576806", null ],
    [ "Initialize", "dd/d39/classScriptInstance.html#a85bdef984cbc4d66a20d1b91303ab00a", null ],
    [ "InsertEvent", "dd/d39/classScriptInstance.html#a0e8edad30577592c08b53c0338aa9374", null ],
    [ "IsDead", "dd/d39/classScriptInstance.html#aa3e2fbd1506cec955e94d0bbef3c9aba", null ],
    [ "IsPaused", "dd/d39/classScriptInstance.html#a1a675a6426792a6b7199eb7bddb6176e", null ],
    [ "IsSleeping", "dd/d39/classScriptInstance.html#a72d12b3a429d669b815fc31bf8efb08b", null ],
    [ "Load", "dd/d39/classScriptInstance.html#a58c2488ef9152c33d350fc70d78f6ca4", null ],
    [ "LoadCompatibilityScripts", "dd/d39/classScriptInstance.html#affaba3214aee814fb9d07df6288bd053", null ],
    [ "LoadDummyScript", "dd/d39/classScriptInstance.html#a5dfeabd99e8c2f645a8eff373e530ff2", null ],
    [ "LoadEmpty", "dd/d39/classScriptInstance.html#ab231ec11924485ba119f996416ec727a", null ],
    [ "LoadObjects", "dd/d39/classScriptInstance.html#ac46eff7e545e0c520988b2adca280858", null ],
    [ "Pause", "dd/d39/classScriptInstance.html#a7fa42952b2e6b7f0bb35c3ad365a7ce7", null ],
    [ "RegisterAPI", "dd/d39/classScriptInstance.html#a0e3f3a36799e25f710a8ee5eb2174583", null ],
    [ "Save", "dd/d39/classScriptInstance.html#a5371b9d0408c44a2228fc00fa52cb2af", null ],
    [ "SaveEmpty", "dd/d39/classScriptInstance.html#a3e820ea88d8214531460b635afe538c2", null ],
    [ "SaveObject", "dd/d39/classScriptInstance.html#a8ed0e33bda2febaef5fee8435a218cf7", null ],
    [ "Unpause", "dd/d39/classScriptInstance.html#a0f1983e1da438346df9e404e91a3b1ee", null ],
    [ "ScriptController", "dd/d39/classScriptInstance.html#a3c560fa455ba2ebcad597ac4e5bd94d2", null ],
    [ "ScriptObject", "dd/d39/classScriptInstance.html#a88a672b3753c3576bcd29e27e212447f", null ],
    [ "callback", "dd/d39/classScriptInstance.html#a883fbfc01e4d7a634eb534c99550e60a", null ],
    [ "controller", "dd/d39/classScriptInstance.html#ad2672b78008d1199f87c52642e68f561", null ],
    [ "engine", "dd/d39/classScriptInstance.html#a33dde108eb73328df4a7ae1a570f6475", null ],
    [ "instance", "dd/d39/classScriptInstance.html#a7d3c0f44f0e959f83671f051e50acb88", null ],
    [ "is_dead", "dd/d39/classScriptInstance.html#a911189cb848877e69d584e5053c0c86b", null ],
    [ "is_paused", "dd/d39/classScriptInstance.html#af65ddc94abc06fa2a59ec9f6b4003b39", null ],
    [ "is_save_data_on_stack", "dd/d39/classScriptInstance.html#a5ca2fe8b40d6d85c61633a2f3a72cd31", null ],
    [ "is_started", "dd/d39/classScriptInstance.html#aeab6eb1ae7a2c07550277ade1d72ff50", null ],
    [ "storage", "dd/d39/classScriptInstance.html#af2dad9fe54bb0d99c5db2e11d1eecac1", null ],
    [ "suspend", "dd/d39/classScriptInstance.html#ac1e12eeda02b803b422ea4e9f5c6a263", null ],
    [ "versionAPI", "dd/d39/classScriptInstance.html#afd134d985161735df7c4e550931c0fc3", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dd/d39/classScriptInstance.js <==
var classScriptInstance =
[
    [ "ScriptInstance", "dd/d39/classScriptInstance.html#af38fe06832c537f369d376215c4c69ca", null ],
    [ "~ScriptInstance", "dd/d39/classScriptInstance.html#a7225244e2a3a774ca3ac704a5e14b58f", null ],
    [ "CallLoad", "dd/d39/classScriptInstance.html#a8ee5b1ffbff379e1edb4beb9009609c9", null ],
    [ "CollectGarbage", "dd/d39/classScriptInstance.html#a4b31a3351ff66fbfe23877ed764fbbea", null ],
    [ "Continue", "dd/d39/classScriptInstance.html#aab6ccc82d56c4fd0bd194e83de3c1ae1", null ],
    [ "Died", "dd/d39/classScriptInstance.html#a1be2376dfdb1b414f89fa8e84835eba9", null ],
    [ "DoCommandCallback", "dd/d39/classScriptInstance.html#a16b00099cd72f705afe49d6b50f5465e", null ],
    [ "DoCommandReturn", "dd/d39/classScriptInstance.html#a3a2942c82ee4448280f2fc38d70a730d", null ],
    [ "DoCommandReturnGoalID", "dd/d39/classScriptInstance.html#a631e44a7f9f88430b84d7391cb5d4bee", null ],
    [ "DoCommandReturnGroupID", "dd/d39/classScriptInstance.html#a63fdbc5eb56df504c9550b312302b5be", null ],
    [ "DoCommandReturnSignID", "dd/d39/classScriptInstance.html#ad282a9e3c9ee1fcc86c5ee65f09a0269", null ],
    [ "DoCommandReturnStoryPageElementID", "dd/d39/classScriptInstance.html#a4b8add72ae20706d80355e472c655613", null ],
    [ "DoCommandReturnStoryPageID", "dd/d39/classScriptInstance.html#af0e89da5f19d101c0f735300fb5881b8", null ],
    [ "DoCommandReturnVehicleID", "dd/d39/classScriptInstance.html#a618bcb3251946270e392ca335ceae293", null ],
    [ "FindLibrary", "dd/d39/classScriptInstance.html#aa240df381cec1162969036894adaf097", null ],
    [ "GameLoop", "dd/d39/classScriptInstance.html#ab76bed5f630ca1c9f67254a52241759f", null ],
    [ "GetAllocatedMemory", "dd/d39/classScriptInstance.html#a97fb3cc92c468131083dd33b1011e9d0", null ],
    [ "GetController", "dd/d39/classScriptInstance.html#ab5e38aa6be21cb868724a906ab691b64", null ],
    [ "GetDoCommandCallback", "dd/d39/classScriptInstance.html#a77474f760f63c96c8ac633dacd9fb9d1", null ],
    [ "GetLogPointer", "dd/d39/classScriptInstance.html#ae6de76c5aee031f5f6eb84865875e841", null ],
    [ "GetOpsTillSuspend", "dd/d39/classScriptInstance.html#adc95ae26f0623017b8cb6ab9dba1668b", null ],
    [ "GetSetting", "dd/d39/classScriptInstance.html#ae75399348a1920f935c840b828d7d274", null ],
    [ "GetStorage", "dd/d39/classScriptInstance.html#a186863f4bf0683092173c1286c576806", null ],
    [ "Initialize", "dd/d39/classScriptInstance.html#a85bdef984cbc4d66a20d1b91303ab00a", null ],
    [ "InsertEvent", "dd/d39/classScriptInstance.html#a0e8edad30577592c08b53c0338aa9374", null ],
    [ "InShutdown", "dd/d39/classScriptInstance.html#a9f14985fc42dc4c190ea9b02dc13665b", null ],
    [ "IsDead", "dd/d39/classScriptInstance.html#aa3e2fbd1506cec955e94d0bbef3c9aba", null ],
    [ "IsPaused", "dd/d39/classScriptInstance.html#a1a675a6426792a6b7199eb7bddb6176e", null ],
    [ "IsSleeping", "dd/d39/classScriptInstance.html#a72d12b3a429d669b815fc31bf8efb08b", null ],
    [ "Load", "dd/d39/classScriptInstance.html#a58c2488ef9152c33d350fc70d78f6ca4", null ],
    [ "LoadCompatibilityScripts", "dd/d39/classScriptInstance.html#affaba3214aee814fb9d07df6288bd053", null ],
    [ "LoadDummyScript", "dd/d39/classScriptInstance.html#a5dfeabd99e8c2f645a8eff373e530ff2", null ],
    [ "LoadEmpty", "dd/d39/classScriptInstance.html#ab231ec11924485ba119f996416ec727a", null ],
    [ "LoadObjects", "dd/d39/classScriptInstance.html#ac46eff7e545e0c520988b2adca280858", null ],
    [ "Pause", "dd/d39/classScriptInstance.html#a7fa42952b2e6b7f0bb35c3ad365a7ce7", null ],
    [ "RegisterAPI", "dd/d39/classScriptInstance.html#a0e3f3a36799e25f710a8ee5eb2174583", null ],
    [ "ReleaseSQObject", "dd/d39/classScriptInstance.html#a2290c4c269a4791a9b37b12ec34584de", null ],
    [ "Save", "dd/d39/classScriptInstance.html#a5371b9d0408c44a2228fc00fa52cb2af", null ],
    [ "SaveEmpty", "dd/d39/classScriptInstance.html#a3e820ea88d8214531460b635afe538c2", null ],
    [ "SaveObject", "dd/d39/classScriptInstance.html#a8ed0e33bda2febaef5fee8435a218cf7", null ],
    [ "Unpause", "dd/d39/classScriptInstance.html#a0f1983e1da438346df9e404e91a3b1ee", null ],
    [ "ScriptController", "dd/d39/classScriptInstance.html#a3c560fa455ba2ebcad597ac4e5bd94d2", null ],
    [ "ScriptObject", "dd/d39/classScriptInstance.html#a88a672b3753c3576bcd29e27e212447f", null ],
    [ "callback", "dd/d39/classScriptInstance.html#a883fbfc01e4d7a634eb534c99550e60a", null ],
    [ "controller", "dd/d39/classScriptInstance.html#ad2672b78008d1199f87c52642e68f561", null ],
    [ "engine", "dd/d39/classScriptInstance.html#a33dde108eb73328df4a7ae1a570f6475", null ],
    [ "in_shutdown", "dd/d39/classScriptInstance.html#a5ca65580ea3ff630423803d94482e853", null ],
    [ "instance", "dd/d39/classScriptInstance.html#a7d3c0f44f0e959f83671f051e50acb88", null ],
    [ "is_dead", "dd/d39/classScriptInstance.html#a911189cb848877e69d584e5053c0c86b", null ],
    [ "is_paused", "dd/d39/classScriptInstance.html#af65ddc94abc06fa2a59ec9f6b4003b39", null ],
    [ "is_save_data_on_stack", "dd/d39/classScriptInstance.html#a5ca2fe8b40d6d85c61633a2f3a72cd31", null ],
    [ "is_started", "dd/d39/classScriptInstance.html#aeab6eb1ae7a2c07550277ade1d72ff50", null ],
    [ "last_allocated_memory", "dd/d39/classScriptInstance.html#aa7dbbfff713d4720afbf204ca9ae31cf", null ],
    [ "storage", "dd/d39/classScriptInstance.html#af2dad9fe54bb0d99c5db2e11d1eecac1", null ],
    [ "suspend", "dd/d39/classScriptInstance.html#ac1e12eeda02b803b422ea4e9f5c6a263", null ],
    [ "versionAPI", "dd/d39/classScriptInstance.html#afd134d985161735df7c4e550931c0fc3", null ]
];
